==> kubernetes-model-1.0.58-sources.jar: annotations/io/fabric8/openshift/api/model/ImageSourcePathFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.String;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Object;

public class ImageSourcePathFluentImpl<A extends ImageSourcePathFluent<A>> extends BaseFluent<A> implements ImageSourcePathFluent<A>{

    private String destinationDir;
    private String sourcePath;

    public ImageSourcePathFluentImpl(){
    }
    public ImageSourcePathFluentImpl(ImageSourcePath instance){
            this.withDestinationDir(instance.getDestinationDir()); 
            this.withSourcePath(instance.getSourcePath()); 
    }

    public String getDestinationDir(){
            return this.destinationDir;
    }

    public A withDestinationDir(String destinationDir){
            this.destinationDir=destinationDir; return (A) this;
    }

    public String getSourcePath(){
            return this.sourcePath;
    }

    public A withSourcePath(String sourcePath){
            this.sourcePath=sourcePath; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageSourcePathFluentImpl that = (ImageSourcePathFluentImpl) o;
            if (destinationDir != null ? !destinationDir.equals(that.destinationDir) :that.destinationDir != null) return false;
            if (sourcePath != null ? !sourcePath.equals(that.sourcePath) :that.sourcePath != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/openshift/api/model/ImageSourcePathFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ImageSourcePathFluentImpl<A extends ImageSourcePathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ImageSourcePathFluent<A>{

    private String destinationDir;
    private String sourcePath;

    public ImageSourcePathFluentImpl(){
    }
    public ImageSourcePathFluentImpl(ImageSourcePath instance){
            this.withDestinationDir(instance.getDestinationDir()); 
            this.withSourcePath(instance.getSourcePath()); 
    }

    public String getDestinationDir(){
            return this.destinationDir;
    }

    public A withDestinationDir(String destinationDir){
            this.destinationDir=destinationDir; return (A) this;
    }

    public String getSourcePath(){
            return this.sourcePath;
    }

    public A withSourcePath(String sourcePath){
            this.sourcePath=sourcePath; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageSourcePathFluentImpl that = (ImageSourcePathFluentImpl) o;
            if (destinationDir != null ? !destinationDir.equals(that.destinationDir) :that.destinationDir != null) return false;
            if (sourcePath != null ? !sourcePath.equals(that.sourcePath) :that.sourcePath != null) return false;
            return true;
    }




}
